"""
(c) 2023 LLC «DACOM M»
"""

from veilrpc.utils.bazalt import states_response
from veilrpc.utils.dpi import PacketCapture


@states_response
def pcap_configuration_receiver(action: str, uuid: str, config: dict) -> dict:
    """
    Состояние представляет собой функцию - приёмник конфигурации утилиты, производящей захват пакетов.
    :param action: Действие, ответ на вопрос: "Что делаем с полученной конфигурацией?".
    :param uuid: Уникальный идентификатор PCAP объекта.
    :param config: Конфигурация PCAP утилиты.
    :return: Результат предпринятого действия.
    """

    pcap = PacketCapture(uuid=uuid, **config)
    return pcap.execute(action)


@states_response
def pcap_configurations_receiver(action: str, configs: dict = None) -> dict:
    """
    Состояние представляет собой функцию - приёмник конфигурации утилиты, производящей захват пакетов.
    :param action: Действие, ответ на вопрос: "Что делаем с полученной конфигурацией?".
    :param configs: Конфигурация PCAP утилиты.
    :return: Результат предпринятого действия.
    """

    for uuid, config in configs.items():
        if not config:
            config = {}
        pcap = PacketCapture(uuid=uuid, **config)
        pcap.execute(action)
    return {'status': 'success', 'status_reason': 'Packet Capturing Configurations received successfully.'}
